@@ -980,3 +980,8 @@ if (\Froxlor\Froxlor::isFroxlorVersion('0.10.34')) {
 	showUpdateStep("Updating from 0.10.34 to 0.10.34.1", false);
 	\Froxlor\Froxlor::updateToVersion('0.10.34.1');
 }
+
+if (\Froxlor\Froxlor::isFroxlorVersion('0.10.34.1')) {
+	showUpdateStep("Updating from 0.10.34.1 to 0.10.35", false);
+	\Froxlor\Froxlor::updateToVersion('0.10.34');
+}
